@@ -70,7 +70,7 @@ module NumRu
     
     class << NetCDF
        def clean_tmpfile(path)
-	  lambda{
+	  proc {
 	     print "removing ", path, "..." if $DEBUG
 	     if File.exist?(path)
 		File.unlink(path) 
@@ -309,11 +309,14 @@ module NumRu
 	 cao = nil
        end
        if csf and cao
-	 (na - cao) / csf
+	 packed = (na - cao) / csf
        elsif csf
-	 na / csf
+	 packed = na / csf
        elsif cao
-	 na - cao
+	 packed = na - cao
+       end
+       if self.typecode <= NArray::LINT
+         packed = packed.round
        end
      end
    end
@@ -655,7 +658,9 @@ module NumRu
 	   na_tmp = self[*a_new]
 	   if n==0 then
 	     k = at
-	     a[0..at-1].each{|x| if x.is_a?(Fixnum) then k -= 1 end}
+	     if at > 0
+	       a[0..at-1].each{|x| if x.is_a?(Fixnum) then k -= 1 end}
+	     end
 	     shape_tmp = na_tmp.shape
 	     shape_tmp[k] = i.length
 	     na = na_tmp.class.new(na_tmp.typecode,*shape_tmp)
